@@ -19,6 +19,6 @@ async def jwks_get(api_implementation: APIInterface, api_options: APIOptions):
         return None
 
     result = await api_implementation.jwks_get(api_options)
-    api_options.response.set_content(result.to_json())
+    api_options.response.set_json_content(result.to_json())
 
     return api_options.response
