@@ -23,5 +23,5 @@ async def handle_refresh_api(api_implementation: APIInterface, api_options: APIO
     if api_implementation.disable_refresh_post or api_implementation.refresh_post is None:
         return None
     await api_implementation.refresh_post(api_options)
-    api_options.response.set_content({})
+    api_options.response.set_json_content({})
     return api_options.response
